@@ -35,7 +35,7 @@
 # it should still work.
 #
 # buildlibs.sh will download, build and install zlib, libogg, libvorbis,
-# flac, id3lib, taglib, libav, chromaprint. You are then ready to build Kid3
+# flac, id3lib, taglib, ffmpeg, chromaprint. You are then ready to build Kid3
 # from the win32 or macosx directories by starting buildkid3.bat (Windows) or
 # buildkid3.sh (Mac).
 
@@ -49,20 +49,22 @@ test ${kernel:0:5} = "MINGW" && kernel="MINGW"
 
 compiler="gcc"
 
-qt_version=5.4.1
+qt_version=5.5.0
 zlib_version=1.2.8
 zlib_patchlevel=2
 libogg_version=1.3.2
 libogg_patchlevel=1
 libvorbis_version=1.3.4
-libvorbis_patchlevel=2
-libav_version=11.3
-libav_patchlevel=1
+libvorbis_patchlevel=3
+ffmpeg_version=2.8
+ffmpeg_patchlevel=1
+#libav_version=11.4
+#libav_patchlevel=2
 libflac_version=1.3.1
-libflac_patchlevel=1
+libflac_patchlevel=4
 id3lib_version=3.8.3
-id3lib_patchlevel=16
-taglib_version=1.9.1
+id3lib_patchlevel=16.2
+taglib_version=1.10beta
 chromaprint_version=1.2
 chromaprint_patchlevel=1
 mp4v2_version=2.0.0
@@ -191,6 +193,13 @@ $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/z/zlib/zlib_${zlib_version}.
 test -f zlib_${zlib_version}.dfsg.orig.tar.gz ||
 $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/z/zlib/zlib_${zlib_version}.dfsg.orig.tar.gz
 
+if test -n "${ffmpeg_version}"; then
+test -f ffmpeg_${ffmpeg_version}.orig.tar.gz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/f/ffmpeg/ffmpeg_${ffmpeg_version}.orig.tar.gz
+test -f ffmpeg_${ffmpeg_version}-${ffmpeg_patchlevel}.debian.tar.xz ||
+$DOWNLOAD http://ftp.de.debian.org/debian/pool/main/f/ffmpeg/ffmpeg_${ffmpeg_version}-${ffmpeg_patchlevel}.debian.tar.xz
+ffmpeg_dir=ffmpeg-${ffmpeg_version}
+else
 if test "${libav_version%.*}" = "0.8"; then
 test -f libav_${libav_version}.orig.tar.gz ||
 $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/liba/libav/libav_${libav_version}.orig.tar.gz
@@ -201,6 +210,8 @@ test -f libav_${libav_version}.orig.tar.xz ||
 $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/liba/libav/libav_${libav_version}.orig.tar.xz
 test -f libav_${libav_version}-${libav_patchlevel}.debian.tar.xz ||
 $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/liba/libav/libav_${libav_version}-${libav_patchlevel}.debian.tar.xz
+ffmpeg_dir=libav-${libav_version}
+fi
 fi
 
 test -f chromaprint_${chromaprint_version}.orig.tar.gz ||
@@ -218,13 +229,13 @@ $DOWNLOAD http://ftp.de.debian.org/debian/pool/main/m/mp4v2/mp4v2_${mp4v2_versio
 if test "$compiler" = "cross-mingw"; then
 test -f mingw.cmake ||
 cat >mingw.cmake <<EOF
-set(QT_PREFIX /windows/Qt/Qt${qt_version}/${qt_version%.?}/mingw491_32)
+set(QT_PREFIX /windows/Qt/Qt${qt_version}/${qt_version%.?}/mingw492_32)
 
 set(CMAKE_SYSTEM_NAME Windows)
 set(CMAKE_C_COMPILER ${cross_host}-gcc)
 set(CMAKE_CXX_COMPILER ${cross_host}-g++)
 set(CMAKE_RC_COMPILER ${cross_host}-windres)
-set(CMAKE_FIND_ROOT_PATH /usr/${cross_host} \${QT_PREFIX} $thisdir/buildroot/usr/local $thisdir/zlib-$zlib_version/inst/usr/local $thisdir/libav-$libav_version/inst/usr/local)
+set(CMAKE_FIND_ROOT_PATH /usr/${cross_host} \${QT_PREFIX} $thisdir/buildroot/usr/local $thisdir/zlib-$zlib_version/inst/usr/local $thisdir/$ffmpeg_dir/inst/usr/local)
 set(CMAKE_FIND_ROOT_PATH_MODE_PROGRAM NEVER)
 set(CMAKE_FIND_ROOT_PATH_MODE_LIBRARY ONLY)
 set(CMAKE_FIND_ROOT_PATH_MODE_INCLUDE ONLY)
@@ -511,25 +522,286 @@ cat >taglib_bvreplace.patch <<"EOF"
  }
 EOF
 
-if test "${libav_version%.*}" = "0.8"; then
-test -f libav_sws.patch ||
-cat >libav_sws.patch <<"EOF"
---- cmdutils.c.org      2011-09-17 13:36:43.000000000 -0700
-+++ cmdutils.c  2011-09-17 15:54:37.453134577 -0700
-@@ -311,6 +311,11 @@
-     const AVOption *oc, *of, *os;
-     char opt_stripped[128];
-     const char *p;
-+// SPage: avoid sws_get_class failure
-+#if !CONFIG_SWSCALE
-+#   define sws_get_class(x)  0
+test -f taglib_podcast.patch ||
+cat >taglib_podcast.patch <<"EOF"
+diff --git a/taglib/CMakeLists.txt b/taglib/CMakeLists.txt
+index 73c1a2f..31e2c49 100644
+--- a/taglib/CMakeLists.txt
++++ b/taglib/CMakeLists.txt
+@@ -83,6 +83,7 @@ set(tag_HDRS
+   mpeg/id3v2/frames/urllinkframe.h
+   mpeg/id3v2/frames/chapterframe.h
+   mpeg/id3v2/frames/tableofcontentsframe.h
++  mpeg/id3v2/frames/podcastframe.h
+   ogg/oggfile.h
+   ogg/oggpage.h
+   ogg/oggpageheader.h
+@@ -177,6 +178,7 @@ set(frames_SRCS
+   mpeg/id3v2/frames/urllinkframe.cpp
+   mpeg/id3v2/frames/chapterframe.cpp
+   mpeg/id3v2/frames/tableofcontentsframe.cpp
++  mpeg/id3v2/frames/podcastframe.cpp
+ )
+ 
+ set(ogg_SRCS
+diff --git a/taglib/mpeg/id3v2/frames/podcastframe.cpp b/taglib/mpeg/id3v2/frames/podcastframe.cpp
+new file mode 100644
+index 0000000..5115a7d
+--- /dev/null
++++ b/taglib/mpeg/id3v2/frames/podcastframe.cpp
+@@ -0,0 +1,79 @@
++/***************************************************************************
++    copyright            : (C) 2015 by Urs Fleisch
++    email                : ufleisch@users.sourceforge.net
++ ***************************************************************************/
++
++/***************************************************************************
++ *   This library is free software; you can redistribute it and/or modify  *
++ *   it  under the terms of the GNU Lesser General Public License version  *
++ *   2.1 as published by the Free Software Foundation.                     *
++ *                                                                         *
++ *   This library is distributed in the hope that it will be useful, but   *
++ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
++ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
++ *   Lesser General Public License for more details.                       *
++ *                                                                         *
++ *   You should have received a copy of the GNU Lesser General Public      *
++ *   License along with this library; if not, write to the Free Software   *
++ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
++ *   02110-1301  USA                                                       *
++ *                                                                         *
++ *   Alternatively, this file is available under the Mozilla Public        *
++ *   License Version 1.1.  You may obtain a copy of the License at         *
++ *   http://www.mozilla.org/MPL/                                           *
++ ***************************************************************************/
++
++#include "podcastframe.h"
++
++using namespace TagLib;
++using namespace ID3v2;
++
++class PodcastFrame::PodcastFramePrivate
++{
++public:
++  ByteVector fieldData;
++};
++
++////////////////////////////////////////////////////////////////////////////////
++// public members
++////////////////////////////////////////////////////////////////////////////////
++
++PodcastFrame::PodcastFrame() : Frame("PCST")
++{
++  d = new PodcastFramePrivate;
++  d->fieldData = ByteVector(4, '\0');
++}
++
++PodcastFrame::~PodcastFrame()
++{
++  delete d;
++}
++
++String PodcastFrame::toString() const
++{
++  return String();
++}
++
++////////////////////////////////////////////////////////////////////////////////
++// protected members
++////////////////////////////////////////////////////////////////////////////////
++
++void PodcastFrame::parseFields(const ByteVector &data)
++{
++  d->fieldData = data;
++}
++
++ByteVector PodcastFrame::renderFields() const
++{
++  return d->fieldData;
++}
++
++////////////////////////////////////////////////////////////////////////////////
++// private members
++////////////////////////////////////////////////////////////////////////////////
++
++PodcastFrame::PodcastFrame(const ByteVector &data, Header *h) : Frame(h)
++{
++  d = new PodcastFramePrivate;
++  parseFields(fieldData(data));
++}
+diff --git a/taglib/mpeg/id3v2/frames/podcastframe.h b/taglib/mpeg/id3v2/frames/podcastframe.h
+new file mode 100644
+index 0000000..7bbc213
+--- /dev/null
++++ b/taglib/mpeg/id3v2/frames/podcastframe.h
+@@ -0,0 +1,80 @@
++/***************************************************************************
++    copyright            : (C) 2015 by Urs Fleisch
++    email                : ufleisch@users.sourceforge.net
++ ***************************************************************************/
++
++/***************************************************************************
++ *   This library is free software; you can redistribute it and/or modify  *
++ *   it  under the terms of the GNU Lesser General Public License version  *
++ *   2.1 as published by the Free Software Foundation.                     *
++ *                                                                         *
++ *   This library is distributed in the hope that it will be useful, but   *
++ *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
++ *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
++ *   Lesser General Public License for more details.                       *
++ *                                                                         *
++ *   You should have received a copy of the GNU Lesser General Public      *
++ *   License along with this library; if not, write to the Free Software   *
++ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
++ *   02110-1301  USA                                                       *
++ *                                                                         *
++ *   Alternatively, this file is available under the Mozilla Public        *
++ *   License Version 1.1.  You may obtain a copy of the License at         *
++ *   http://www.mozilla.org/MPL/                                           *
++ ***************************************************************************/
++
++#ifndef TAGLIB_PODCASTFRAME_H
++#define TAGLIB_PODCASTFRAME_H
++
++#include "id3v2frame.h"
++#include "taglib_export.h"
++
++namespace TagLib {
++
++  namespace ID3v2 {
++
++    //! ID3v2 podcast frame
++    /*!
++     * An implementation of ID3v2 podcast flag, a frame with four zero bytes.
++     */
++    class TAGLIB_EXPORT PodcastFrame : public Frame
++    {
++      friend class FrameFactory;
++
++    public:
++      /*!
++       * Construct a podcast frame.
++       */
++      PodcastFrame();
++
++      /*!
++       * Destroys this PodcastFrame instance.
++       */
++      virtual ~PodcastFrame();
++
++      /*!
++       * Returns a null string.
++       */
++      virtual String toString() const;
++
++    protected:
++      // Reimplementations.
++
++      virtual void parseFields(const ByteVector &data);
++      virtual ByteVector renderFields() const;
++
++    private:
++      /*!
++       * The constructor used by the FrameFactory.
++       */
++      PodcastFrame(const ByteVector &data, Header *h);
++      PodcastFrame(const PodcastFrame &);
++      PodcastFrame &operator=(const PodcastFrame &);
++
++      class PodcastFramePrivate;
++      PodcastFramePrivate *d;
++    };
++
++  }
++}
 +#endif
+diff --git a/taglib/mpeg/id3v2/id3v2frame.cpp b/taglib/mpeg/id3v2/id3v2frame.cpp
+index bee5375..4313bcc 100644
+--- a/taglib/mpeg/id3v2/id3v2frame.cpp
++++ b/taglib/mpeg/id3v2/id3v2frame.cpp
+@@ -117,7 +117,8 @@ Frame *Frame::createTextualFrame(const String &key, const StringList &values) //
+   // check if the key is contained in the key<=>frameID mapping
+   ByteVector frameID = keyToFrameID(key);
+   if(!frameID.isNull()) {
+-    if(frameID[0] == 'T'){ // text frame
++    // Apple proprietary WFED (Podcast URL) is in fact a text frame.
++    if(frameID[0] == 'T' || frameID == "WFED"){ // text frame
+       TextIdentificationFrame *frame = new TextIdentificationFrame(frameID, String::UTF8);
+       frame->setText(values);
+       return frame;
+@@ -427,6 +428,12 @@ static const char *frameTranslation[][2] = {
+   // Other frames
+   { "COMM", "COMMENT" },
+   //{ "USLT", "LYRICS" }, handled specially
++  // Apple iTunes proprietary frames
++  { "PCST", "PODCAST" },
++  { "TCAT", "PODCASTCATEGORY" },
++  { "TDES", "PODCASTDESC" },
++  { "TGID", "PODCASTID" },
++  { "WFED", "PODCASTURL" },
+ };
+ 
+ static const TagLib::uint txxxFrameTranslationSize = 8;
+@@ -532,7 +539,8 @@ PropertyMap Frame::asProperties() const
+   // workaround until this function is virtual
+   if(id == "TXXX")
+     return dynamic_cast< const UserTextIdentificationFrame* >(this)->asProperties();
+-  else if(id[0] == 'T')
++  // Apple proprietary WFED (Podcast URL) is in fact a text frame.
++  else if(id[0] == 'T' || id == "WFED")
+     return dynamic_cast< const TextIdentificationFrame* >(this)->asProperties();
+   else if(id == "WXXX")
+     return dynamic_cast< const UserUrlLinkFrame* >(this)->asProperties();
+diff --git a/taglib/mpeg/id3v2/id3v2framefactory.cpp b/taglib/mpeg/id3v2/id3v2framefactory.cpp
+index f6a4aac..bf4b0ee 100644
+--- a/taglib/mpeg/id3v2/id3v2framefactory.cpp
++++ b/taglib/mpeg/id3v2/id3v2framefactory.cpp
+@@ -49,6 +49,7 @@
+ #include "frames/eventtimingcodesframe.h"
+ #include "frames/chapterframe.h"
+ #include "frames/tableofcontentsframe.h"
++#include "frames/podcastframe.h"
+ 
+ using namespace TagLib;
+ using namespace ID3v2;
+@@ -167,7 +168,8 @@ Frame *FrameFactory::createFrame(const ByteVector &origData, Header *tagHeader)
+ 
+   // Text Identification (frames 4.2)
+ 
+-  if(frameID.startsWith("T")) {
++  // Apple proprietary WFED (Podcast URL) is in fact a text frame.
++  if(frameID.startsWith("T") || frameID == "WFED") {
+ 
+     TextIdentificationFrame *f = frameID != "TXXX"
+       ? new TextIdentificationFrame(data, header)
+@@ -287,6 +289,11 @@ Frame *FrameFactory::createFrame(const ByteVector &origData, Header *tagHeader)
+   if(frameID == "CTOC")
+     return new TableOfContentsFrame(tagHeader, data, header);
+ 
++  // Apple proprietary PCST (Podcast)
++
++  if(frameID == "PCST")
++    return new PodcastFrame(data, header);
++
+   return new UnknownFrame(data, header);
+ }
+ 
+@@ -423,6 +430,14 @@ bool FrameFactory::updateFrame(Frame::Header *header) const
+     convertFrame("WPB", "WPUB", header);
+     convertFrame("WXX", "WXXX", header);
+ 
++    // Apple iTunes nonstandard frames
++    convertFrame("PCS", "PCST", header);
++    convertFrame("TCT", "TCAT", header);
++    convertFrame("TDR", "TDRL", header);
++    convertFrame("TDS", "TDES", header);
++    convertFrame("TID", "TGID", header);
++    convertFrame("WFD", "WFED", header);
 +
-     const AVClass *cc = avcodec_get_class(), *fc = avformat_get_class(), *sc = sws_get_class();
+     break;
+   }
  
-     if (!(p = strchr(opt, ':')))
 EOF
-fi
 
 test -f mp4v2_win32.patch ||
 cat >mp4v2_win32.patch <<"EOF"
@@ -1798,8 +2070,13 @@ if ! test -d taglib-${taglib_version}; then
 tar xzf source/taglib-${taglib_version}.tar.gz
 cd taglib-${taglib_version}/
 taglib_nr=${taglib_version:0:3}
-taglib_nr=${taglib_nr/./}
-if test $taglib_nr -ge 18; then
+if test $taglib_nr = "1.1"; then
+  taglib_nr=${taglib_version:0:4}
+  taglib_nr=${taglib_nr/./}
+else
+  taglib_nr=${taglib_nr/./0}
+fi
+if test $taglib_nr -ge 108; then
   patch -p1 <../source/taglib-msvc.patch
 else
   sed -i 's/^ADD_SUBDIRECTORY(bindings)/#ADD_SUBDIRECTORY(bindings)/' ./CMakeLists.txt
@@ -1807,12 +2084,21 @@ else
 fi
 if test "${taglib_version}" = "1.9.1"; then
   patch -p1 <../source/taglib_bvreplace.patch
+elif test "${taglib_version:0:4}" = "1.10"; then
+  patch -p1 <../source/taglib_podcast.patch
 fi
 cd ..
 fi
 
-echo "### Extracting libav"
+echo "### Extracting ffmpeg"
 
+if test -n "${ffmpeg_version}"; then
+tar xzf source/ffmpeg_${ffmpeg_version}.orig.tar.gz 
+cd ffmpeg-${ffmpeg_version}/
+unxz -c ../source/ffmpeg_${ffmpeg_version}-${ffmpeg_patchlevel}.debian.tar.xz | tar x
+for f in $(cat debian/patches/series); do patch -p1 <debian/patches/$f; done
+cd ..
+else
 if test "${libav_version%.*}" = "0.8"; then
 if ! test -d libav-${libav_version}; then
 tar xzf source/libav_${libav_version}.orig.tar.gz
@@ -1827,7 +2113,6 @@ for f in $(cat debian/patches/series); do
   fi
 done
 IFS=$oldifs
-patch -p0 <../source/libav_sws.patch
 cd ..
 fi
 else
@@ -1848,6 +2133,7 @@ IFS=$oldifs
 cd ..
 fi
 fi
+fi
 
 echo "### Extracting chromaprint"
 
@@ -1950,7 +2236,7 @@ if test "$1" = "clean"; then
   for d in zlib-${zlib_version} libogg-${libogg_version} \
            libvorbis-${libvorbis_version} flac-${libflac_version} \
            id3lib-${id3lib_version} taglib-${taglib_version} \
-           libav-${libav_version} chromaprint-${chromaprint_version} \
+           ${ffmpeg_dir} chromaprint-${chromaprint_version} \
            mp4v2-${mp4v2_version}; do
     rm -rf $d/inst
   done
@@ -2033,7 +2319,11 @@ echo "### Building id3lib"
 
 cd id3lib-${id3lib_version}/
 autoconf
-test -f Makefile || CPPFLAGS=-I/usr/local/include LDFLAGS=-L/usr/local/lib ./configure --enable-shared=no --enable-static=yes $ENABLE_DEBUG $CONFIGURE_OPTIONS
+configure_args="--enable-shared=no --enable-static=yes $ENABLE_DEBUG $CONFIGURE_OPTIONS"
+if test $kernel = "MINGW"; then
+  configure_args="$configure_args --build=mingw32"
+fi
+test -f Makefile || CPPFLAGS=-I/usr/local/include LDFLAGS=-L/usr/local/lib ./configure $configure_args
 SED=sed make
 mkdir -p inst
 make install DESTDIR=`pwd`/inst
@@ -2056,11 +2346,11 @@ tar czf ../../bin/taglib-${taglib_version}.tgz usr
 cd ../..
 fi
 
-if test ! -d libav-${libav_version}/inst; then
-echo "### Building libav"
+if test ! -d ${ffmpeg_dir}/inst; then
+echo "### Building ffmpeg"
 
 if test "${libav_version%.*}" = "0.8"; then
-cd libav-${libav_version}
+cd ${ffmpeg_dir}
 # configure needs yasm and pr
 # On msys, make >= 3.81 is needed.
 # Most options taken from
@@ -2160,10 +2450,10 @@ make
 mkdir -p inst
 make install DESTDIR=`pwd`/inst
 cd inst
-tar czf ../../bin/libav-${libav_version}.tgz usr
+tar czf ../../bin/${ffmpeg_dir}.tgz usr
 cd ../..
 else
-cd libav-${libav_version}
+cd ${ffmpeg_dir}
 # configure needs yasm and pr
 # On msys, make >= 3.81 is needed.
 # Most options taken from
@@ -2183,6 +2473,9 @@ if test $(uname) = "MSYS_NT-6.1"; then
 AV_CONFIGURE_OPTIONS="$AV_CONFIGURE_OPTIONS --target-os=mingw32"
 fi
 fi
+if ( test $kernel = "Darwin" || test $kernel = "MINGW" ) && test -n "${ffmpeg_version}"; then
+AV_CONFIGURE_OPTIONS="$AV_CONFIGURE_OPTIONS --disable-iconv"
+fi
 if test -z "$ENABLE_DEBUG"; then
 AV_CONFIGURE_OPTIONS="$AV_CONFIGURE_OPTIONS --disable-debug"
 else
@@ -2269,7 +2562,7 @@ make
 mkdir -p inst
 make install DESTDIR=`pwd`/inst
 cd inst
-tar czf ../../bin/libav-${libav_version}.tgz usr
+tar czf ../../bin/${ffmpeg_dir}.tgz usr
 cd ../..
 fi
 fi
@@ -2279,7 +2572,7 @@ echo "### Building chromaprint"
 
 # The zlib library path was added for MinGW-builds GCC 4.7.2.
 cd chromaprint-${chromaprint_version}/
-test -f Makefile || eval cmake -DBUILD_SHARED_LIBS=OFF -DEXTRA_LIBS=\"-L$thisdir/zlib-$zlib_version/inst/usr/local/lib -lz\" -DFFMPEG_ROOT=$thisdir/libav-$libav_version/inst/usr/local $CMAKE_BUILD_TYPE_DEBUG $CMAKE_OPTIONS
+test -f Makefile || eval cmake -DBUILD_SHARED_LIBS=OFF -DEXTRA_LIBS=\"-L$thisdir/zlib-$zlib_version/inst/usr/local/lib -lz\" -DFFMPEG_ROOT=$thisdir/$ffmpeg_dir/inst/usr/local $CMAKE_BUILD_TYPE_DEBUG $CMAKE_OPTIONS
 mkdir -p inst
 make install DESTDIR=`pwd`/inst
 fixcmakeinst
@@ -2340,7 +2633,7 @@ done
 for f in po/*.qm; do
   l=${f#*_};
   l=${l%.qm};
-  test -f $QT_TRANSLATIONS_DIR/qt_$l.qm && cp $QT_TRANSLATIONS_DIR/qt_$l.qm $INSTDIR
+  test -f $QT_TRANSLATIONS_DIR/qtbase_$l.qm && cp $QT_TRANSLATIONS_DIR/qtbase_$l.qm $INSTDIR
 done
 
 rm -f $INSTDIR.zip
@@ -2348,10 +2641,12 @@ rm -f $INSTDIR.zip
 EOF
       chmod +x kid3/make_package.sh
     else
+      taglib_config_version=$taglib_version
+      test $taglib_config_version = "1.10beta" && taglib_config_version="1.10.0"
       cat >kid3/build.sh <<EOF
 BUILDPREFIX=\$(cd ..; pwd)/buildroot/usr/local
 export PKG_CONFIG_PATH=\$BUILDPREFIX/lib/pkgconfig
-cmake -DWITH_TAGLIB=OFF -DHAVE_TAGLIB=1 -DTAGLIB_LIBRARIES:STRING="-L\$BUILDPREFIX/lib -ltag -lz" -DTAGLIB_CFLAGS:STRING="-I\$BUILDPREFIX/include/taglib -I\$BUILDPREFIX/include -DTAGLIB_STATIC" -DTAGLIB_VERSION:STRING="${taglib_version}" -DWITH_QT5=ON -DWITH_QML=OFF -DCMAKE_CXX_FLAGS_DEBUG:STRING="-g -DID3LIB_LINKOPTION=1 -DFLAC__NO_DLL" -DCMAKE_INCLUDE_PATH=\$BUILDPREFIX/include -DCMAKE_LIBRARY_PATH=\$BUILDPREFIX/lib -DCMAKE_PROGRAM_PATH=\$BUILDPREFIX/bin -DWITH_FFMPEG=ON -DFFMPEG_ROOT=\$BUILDPREFIX -DWITH_MP4V2=ON -DCMAKE_BUILD_TYPE=Debug -DBUILD_SHARED_LIBS=OFF -DWITH_GCC_PCH=OFF -DWITH_APPS="Qt;CLI" -DCMAKE_INSTALL_PREFIX= -DWITH_BINDIR=. -DWITH_DATAROOTDIR=. -DWITH_DOCDIR=. -DWITH_TRANSLATIONSDIR=. ../../kid3
+cmake -DWITH_TAGLIB=OFF -DHAVE_TAGLIB=1 -DTAGLIB_LIBRARIES:STRING="-L\$BUILDPREFIX/lib -ltag -lz" -DTAGLIB_CFLAGS:STRING="-I\$BUILDPREFIX/include/taglib -I\$BUILDPREFIX/include -DTAGLIB_STATIC" -DTAGLIB_VERSION:STRING="${taglib_config_version}" -DWITH_QT5=ON -DWITH_QML=OFF -DCMAKE_CXX_FLAGS_DEBUG:STRING="-g -DID3LIB_LINKOPTION=1 -DFLAC__NO_DLL" -DCMAKE_INCLUDE_PATH=\$BUILDPREFIX/include -DCMAKE_LIBRARY_PATH=\$BUILDPREFIX/lib -DCMAKE_PROGRAM_PATH=\$BUILDPREFIX/bin -DWITH_FFMPEG=ON -DFFMPEG_ROOT=\$BUILDPREFIX -DWITH_MP4V2=ON -DCMAKE_BUILD_TYPE=Debug -DBUILD_SHARED_LIBS=OFF -DWITH_GCC_PCH=OFF -DWITH_APPS="Qt;CLI" -DCMAKE_INSTALL_PREFIX= -DWITH_BINDIR=. -DWITH_DATAROOTDIR=. -DWITH_DOCDIR=. -DWITH_TRANSLATIONSDIR=. ../../kid3
 EOF
     fi
     chmod +x kid3/build.sh
@@ -2366,7 +2661,7 @@ tar xmzf bin/libvorbis-${libvorbis_version}.tgz -C $BUILDROOT
 tar xmzf bin/flac-${libflac_version}.tgz -C $BUILDROOT
 tar xmzf bin/id3lib-${id3lib_version}.tgz -C $BUILDROOT
 tar xmzf bin/taglib-${taglib_version}.tgz -C $BUILDROOT
-tar xmzf bin/libav-${libav_version}.tgz -C $BUILDROOT
+tar xmzf bin/${ffmpeg_dir}.tgz -C $BUILDROOT
 tar xmzf bin/chromaprint-${chromaprint_version}.tgz -C $BUILDROOT
 tar xmzf bin/mp4v2-${mp4v2_version}.tgz -C $BUILDROOT
 
