@@ -35,7 +35,7 @@ namespace {
 /**
  * List of picture type strings, NULL terminated.
  */
-static const char* pictureTypeNames[] = {
+static const char* const pictureTypeNames[] = {
   QT_TRANSLATE_NOOP("@default", "Other"),
   QT_TRANSLATE_NOOP("@default", "32x32 pixels PNG file icon"),
   QT_TRANSLATE_NOOP("@default", "Other file icon"),
@@ -60,8 +60,64 @@ static const char* pictureTypeNames[] = {
   NULL
 };
 
+/**
+ * List of untranslated picture type strings, NULL terminated.
+ */
+static const char* const pictureTypeStrings[] = {
+  "Other",
+  "Png Icon",
+  "Icon",
+  "Front",
+  "Back",
+  "Leaflet",
+  "Media",
+  "Lead Artist",
+  "Artist",
+  "Conductor",
+  "Band",
+  "Composer",
+  "Lyricist",
+  "Recording Location",
+  "During Recording",
+  "During Performance",
+  "Video Capture",
+  "Fish",
+  "Illustration",
+  "Band Logotype",
+  "Publisher Logotype",
+  NULL
+};
+
 }
 
+
+/**
+ * Construct properties from a new image.
+ * @param data image data
+ */
+PictureFrame::ImageProperties::ImageProperties(const QByteArray& data)
+{
+  QImage image;
+  if (image.loadFromData(data)) {
+    m_width = image.width();
+    m_height = image.height();
+    m_depth = image.depth();
+#if QT_VERSION >= 0x040600
+    m_numColors = image.colorCount();
+#else
+    m_numColors = image.numColors();
+#endif
+    m_imageHash = qHash(data);
+  } else {
+    m_width = 0;
+    m_height = 0;
+    m_depth = 0;
+    m_numColors = 0;
+    m_imageHash = 0;
+  }
+}
+
+
 /**
  * Constructor.
  *
@@ -77,7 +133,7 @@ PictureFrame::PictureFrame(
   const QString& description,
   PictureType pictureType,
   const QString& mimeType,
-  Field::TextEncoding enc,
+  TextEncoding enc,
   const QString& imgFormat)
 {
   setType(FT_Picture);
@@ -95,7 +151,7 @@ PictureFrame::PictureFrame(const Frame& frame)
   setType(FT_Picture);
 
   // Make sure all fields are available in the correct order
-  Field::TextEncoding enc = Field::TE_ISO8859_1;
+  TextEncoding enc = TE_ISO8859_1;
   PictureType pictureType = PT_CoverFront;
   QString imgFormat(QLatin1String("JPG")), mimeType(QLatin1String("image/jpeg")), description;
   QByteArray data;
@@ -120,40 +176,48 @@ PictureFrame::~PictureFrame()
  * @param pictureType picture type
  * @param description description
  * @param data        binary picture data
+ * @param imgProps    optional METADATA_BLOCK_PICTURE image properties
  */
 void PictureFrame::setFields(Frame& frame,
-                             Field::TextEncoding enc, const QString& imgFormat,
+                             TextEncoding enc, const QString& imgFormat,
                              const QString& mimeType, PictureType pictureType,
-                             const QString& description, const QByteArray& data)
+                             const QString& description, const QByteArray& data,
+                             const ImageProperties* imgProps)
 {
   Field field;
   FieldList& fields = frame.fieldList();
   fields.clear();
 
-  field.m_id = Field::ID_TextEnc;
+  field.m_id = ID_TextEnc;
   field.m_value = enc;
   fields.push_back(field);
 
-  field.m_id = Field::ID_ImageFormat;
+  field.m_id = ID_ImageFormat;
   field.m_value = imgFormat;
   fields.push_back(field);
 
-  field.m_id = Field::ID_MimeType;
+  field.m_id = ID_MimeType;
   field.m_value = mimeType;
   fields.push_back(field);
 
-  field.m_id = Field::ID_PictureType;
+  field.m_id = ID_PictureType;
   field.m_value = pictureType;
   fields.push_back(field);
 
-  field.m_id = Field::ID_Description;
+  field.m_id = ID_Description;
   field.m_value = description;
   fields.push_back(field);
 
-  field.m_id = Field::ID_Data;
+  field.m_id = ID_Data;
   field.m_value = data;
   fields.push_back(field);
 
+  if (imgProps && !imgProps->isNull()) {
+    field.m_id = ID_ImageProperties;
+    field.m_value.setValue(*imgProps);
+    fields.push_back(field);
+  }
+
   frame.setValue(description);
 }
 
@@ -168,34 +232,41 @@ void PictureFrame::setFields(Frame& frame,
  * @param pictureType picture type
  * @param description description
  * @param data        binary picture data
+ * @param imgProps    optional METADATA_BLOCK_PICTURE image properties
  */
 void PictureFrame::getFields(const Frame& frame,
-                             Field::TextEncoding& enc, QString& imgFormat,
+                             TextEncoding& enc, QString& imgFormat,
                              QString& mimeType, PictureType& pictureType,
-                             QString& description, QByteArray& data)
+                             QString& description, QByteArray& data,
+                             ImageProperties* imgProps)
 {
   for (Frame::FieldList::const_iterator it = frame.getFieldList().begin();
        it != frame.getFieldList().end();
        ++it) {
     switch ((*it).m_id) {
-      case Field::ID_TextEnc:
-        enc = static_cast<Field::TextEncoding>((*it).m_value.toInt());
+      case ID_TextEnc:
+        enc = static_cast<TextEncoding>((*it).m_value.toInt());
         break;
-      case Field::ID_ImageFormat:
+      case ID_ImageFormat:
         imgFormat = (*it).m_value.toString();
         break;
-      case Field::ID_MimeType:
+      case ID_MimeType:
         mimeType = (*it).m_value.toString();
         break;
-      case Field::ID_PictureType:
+      case ID_PictureType:
         pictureType = static_cast<PictureType>((*it).m_value.toInt());
         break;
-      case Field::ID_Description:
+      case ID_Description:
         description = (*it).m_value.toString();
         break;
-      case Field::ID_Data:
+      case ID_Data:
         data = (*it).m_value.toByteArray();
         break;
+      case ID_ImageProperties:
+        if (imgProps) {
+          *imgProps = (*it).m_value.value<ImageProperties>();
+        }
+        break;
       default:
         qDebug("Unknown picture field ID");
     }
@@ -210,7 +281,7 @@ void PictureFrame::getFields(const Frame& frame,
  */
 bool PictureFrame::areFieldsEqual(const Frame& f1, const Frame& f2)
 {
-  Field::TextEncoding enc1, enc2;
+  TextEncoding enc1, enc2;
   QString imgFormat1, imgFormat2;
   QString mimeType1, mimeType2;
   PictureType pictureType1, pictureType2;
@@ -231,9 +302,9 @@ bool PictureFrame::areFieldsEqual(const Frame& f1, const Frame& f2)
  *
  * @return true if field found and set.
  */
-bool PictureFrame::setTextEncoding(Frame& frame, Field::TextEncoding enc)
+bool PictureFrame::setTextEncoding(Frame& frame, TextEncoding enc)
 {
-  return setField(frame, Field::ID_TextEnc, enc);
+  return setField(frame, ID_TextEnc, enc);
 }
 
 /**
@@ -244,11 +315,11 @@ bool PictureFrame::setTextEncoding(Frame& frame, Field::TextEncoding enc)
  *
  * @return true if field found.
  */
-bool PictureFrame::getTextEncoding(const Frame& frame, Field::TextEncoding& enc)
+bool PictureFrame::getTextEncoding(const Frame& frame, TextEncoding& enc)
 {
-  QVariant var(getField(frame, Field::ID_TextEnc));
+  QVariant var(getField(frame, ID_TextEnc));
   if (var.isValid()) {
-    enc = static_cast<Field::TextEncoding>(var.toInt());
+    enc = static_cast<TextEncoding>(var.toInt());
     return true;
   }
   return false;
@@ -264,7 +335,7 @@ bool PictureFrame::getTextEncoding(const Frame& frame, Field::TextEncoding& enc)
  */
 bool PictureFrame::setImageFormat(Frame& frame, const QString& imgFormat)
 {
-  return setField(frame, Field::ID_ImageFormat, imgFormat);
+  return setField(frame, ID_ImageFormat, imgFormat);
 }
 
 /**
@@ -277,7 +348,7 @@ bool PictureFrame::setImageFormat(Frame& frame, const QString& imgFormat)
  */
 bool PictureFrame::getImageFormat(const Frame& frame, QString& imgFormat)
 {
-  QVariant var(getField(frame, Field::ID_ImageFormat));
+  QVariant var(getField(frame, ID_ImageFormat));
   if (var.isValid()) {
     imgFormat = var.toString();
     return true;
@@ -295,7 +366,7 @@ bool PictureFrame::getImageFormat(const Frame& frame, QString& imgFormat)
  */
 bool PictureFrame::setMimeType(Frame& frame, const QString& mimeType)
 {
-  return setField(frame, Field::ID_MimeType, mimeType);
+  return setField(frame, ID_MimeType, mimeType);
 }
 
 /**
@@ -308,7 +379,7 @@ bool PictureFrame::setMimeType(Frame& frame, const QString& mimeType)
  */
 bool PictureFrame::getMimeType(const Frame& frame, QString& mimeType)
 {
-  QVariant var(getField(frame, Field::ID_MimeType));
+  QVariant var(getField(frame, ID_MimeType));
   if (var.isValid()) {
     mimeType = var.toString();
     return true;
@@ -326,7 +397,7 @@ bool PictureFrame::getMimeType(const Frame& frame, QString& mimeType)
  */
 bool PictureFrame::setPictureType(Frame& frame, PictureType pictureType)
 {
-  return setField(frame, Field::ID_PictureType, pictureType);
+  return setField(frame, ID_PictureType, pictureType);
 }
 
 /**
@@ -339,7 +410,7 @@ bool PictureFrame::setPictureType(Frame& frame, PictureType pictureType)
  */
 bool PictureFrame::getPictureType(const Frame& frame, PictureType& pictureType)
 {
-  QVariant var(getField(frame, Field::ID_PictureType));
+  QVariant var(getField(frame, ID_PictureType));
   if (var.isValid()) {
     pictureType = static_cast<PictureType>(var.toInt());
     return true;
@@ -357,7 +428,7 @@ bool PictureFrame::getPictureType(const Frame& frame, PictureType& pictureType)
  */
 bool PictureFrame::setDescription(Frame& frame, const QString& description)
 {
-  return setField(frame, Field::ID_Description, description);
+  return setField(frame, ID_Description, description);
 }
 
 /**
@@ -370,7 +441,7 @@ bool PictureFrame::setDescription(Frame& frame, const QString& description)
  */
 bool PictureFrame::getDescription(const Frame& frame, QString& description)
 {
-  QVariant var(getField(frame, Field::ID_Description));
+  QVariant var(getField(frame, ID_Description));
   if (var.isValid()) {
     description = var.toString();
     return true;
@@ -388,7 +459,7 @@ bool PictureFrame::getDescription(const Frame& frame, QString& description)
  */
 bool PictureFrame::setData(Frame& frame, const QByteArray& data)
 {
-  return setField(frame, Field::ID_Data, data);
+  return setField(frame, ID_Data, data);
 }
 
 /**
@@ -401,7 +472,7 @@ bool PictureFrame::setData(Frame& frame, const QByteArray& data)
  */
 bool PictureFrame::getData(const Frame& frame, QByteArray& data)
 {
-  QVariant var(getField(frame, Field::ID_Data));
+  QVariant var(getField(frame, ID_Data));
   if (var.isValid()) {
     data = var.toByteArray();
     return true;
@@ -561,6 +632,7 @@ void PictureFrame::setFieldsFromBase64(Frame& frame, const QString& base64Value)
   PictureFrame::PictureType pictureType = PictureFrame::PT_CoverFront;
   QString mimeType(QLatin1String("image/jpeg"));
   QString description(QLatin1String(""));
+  ImageProperties imgProps;
   if (frame.getInternalName() == QLatin1String("METADATA_BLOCK_PICTURE")) {
     unsigned long baSize = static_cast<unsigned long>(ba.size());
     if (baSize < 32) return;
@@ -578,15 +650,24 @@ void PictureFrame::setFieldsFromBase64(Frame& frame, const QString& base64Value)
     if (baSize < index + descLen + 20) return;
     description = QString::fromUtf8(ba.data() + index, descLen);
     index += descLen;
-    index += 16; // width, height, depth, number of colors
+    uint width, height, depth, numColors;
+    width = getBigEndianULongFromByteArray(ba, index);
+    index += 4;
+    height = getBigEndianULongFromByteArray(ba, index);
+    index += 4;
+    depth = getBigEndianULongFromByteArray(ba, index);
+    index += 4;
+    numColors = getBigEndianULongFromByteArray(ba, index);
+    index += 4;
     unsigned long picLen = getBigEndianULongFromByteArray(ba, index);
     index += 4;
     if (baSize < index + picLen) return;
     ba = ba.mid(index);
+    imgProps = ImageProperties(width, height, depth, numColors, ba);
   }
   PictureFrame::setFields(
-    frame, Frame::Field::TE_UTF8, QLatin1String(""), mimeType,
-    pictureType, description, ba);
+    frame, TE_UTF8, QLatin1String(""), mimeType,
+    pictureType, description, ba, &imgProps);
 }
 
 /**
@@ -597,12 +678,13 @@ void PictureFrame::setFieldsFromBase64(Frame& frame, const QString& base64Value)
  */
 void PictureFrame::getFieldsToBase64(const Frame& frame, QString& base64Value)
 {
-  Frame::Field::TextEncoding enc;
+  TextEncoding enc;
   PictureFrame::PictureType pictureType = PictureFrame::PT_CoverFront;
   QString imgFormat, mimeType, description;
   QByteArray pic;
+  ImageProperties imgProps;
   PictureFrame::getFields(frame, enc, imgFormat, mimeType,
-                          pictureType, description, pic);
+                          pictureType, description, pic, &imgProps);
   if (frame.getInternalName() == QLatin1String("METADATA_BLOCK_PICTURE")) {
     QByteArray mimeStr = mimeType.toLatin1();
     QByteArray descStr = description.toUtf8();
@@ -622,25 +704,17 @@ void PictureFrame::getFieldsToBase64(const Frame& frame, QString& base64Value)
     renderCharsToByteArray(descStr, ba, index, descLen);
     index += descLen;
 
-    int width = 0, height = 0, depth = 0, numColors = 0;
-    QImage image;
-    if (image.loadFromData(pic)) {
-      width = image.width();
-      height = image.height();
-      depth = image.depth();
-#if QT_VERSION >= 0x040600
-      numColors = image.colorCount();
-#else
-      numColors = image.numColors();
-#endif
+    if (!imgProps.isValidForImage(pic)) {
+      imgProps = ImageProperties(pic);
     }
-    renderBigEndianULongToByteArray(width, ba, index);
+
+    renderBigEndianULongToByteArray(imgProps.width(), ba, index);
     index += 4;
-    renderBigEndianULongToByteArray(height, ba, index);
+    renderBigEndianULongToByteArray(imgProps.height(), ba, index);
     index += 4;
-    renderBigEndianULongToByteArray(depth, ba, index);
+    renderBigEndianULongToByteArray(imgProps.depth(), ba, index);
     index += 4;
-    renderBigEndianULongToByteArray(numColors, ba, index);
+    renderBigEndianULongToByteArray(imgProps.numColors(), ba, index);
     index += 4;
 
     renderBigEndianULongToByteArray(picLen, ba, index);
@@ -661,7 +735,8 @@ void PictureFrame::getFieldsToBase64(const Frame& frame, QString& base64Value)
 QString PictureFrame::getPictureTypeName(PictureType type)
 {
   if (type >= 0 &&
-      type < sizeof(pictureTypeNames) / sizeof(pictureTypeNames[0]) - 1) {
+      type < static_cast<int>(
+        sizeof(pictureTypeNames) / sizeof(pictureTypeNames[0]) - 1)) {
     return QCoreApplication::translate("@default", pictureTypeNames[type]);
   }
   return QString();
@@ -670,7 +745,48 @@ QString PictureFrame::getPictureTypeName(PictureType type)
 /**
  * List of picture type strings, NULL terminated.
  */
-const char** PictureFrame::getPictureTypeNames()
+const char* const* PictureFrame::getPictureTypeNames()
 {
   return pictureTypeNames;
 }
+
+/**
+ * Get an untranslated string for a picture type.
+ *
+ * @param type picture type
+ *
+ * @return picture type, 0 if unknown.
+ */
+const char* PictureFrame::getPictureTypeString(PictureType type)
+{
+  return type >= 0 && type < static_cast<int>(
+        sizeof(pictureTypeStrings) / sizeof(pictureTypeStrings[0]) - 1)
+      ? pictureTypeStrings[type] : 0;
+}
+
+/**
+ * List of untranslated picture type strings, NULL terminated.
+ */
+const char* const* PictureFrame::getPictureTypeStrings()
+{
+  return pictureTypeStrings;
+}
+
+/**
+ * Get picture type from an untranslated string.
+ *
+ * @param str untranslated picture type string
+ *
+ * @return picture type, PT_Other if unknown.
+ */
+PictureFrame::PictureType PictureFrame::getPictureTypeFromString(const char* str)
+{
+  for (unsigned int i = 0;
+       i < sizeof(pictureTypeStrings) / sizeof(pictureTypeStrings[0]) - 1;
+       ++i) {
+    if (qstricmp(str, pictureTypeStrings[i]) == 0) {
+      return static_cast<PictureType>(i);
+    }
+  }
+  return PT_Other;
+}
